@@ -15,6 +15,8 @@
 #include <sys/sysctl.h>
 #include <unistd.h>
 
+#include "debug.h"
+
 template <typename T>
 bool readSysctl(const char *name, T *buffer, size_t size = sizeof(T))
 {
@@ -31,7 +33,7 @@ FreeBsdMemoryBackend::FreeBsdMemoryBackend(KSysGuard::SensorContainer* container
     // indicates that we do not want to directly access kernel memory.
     m_kd = kvm_openfiles(nullptr, "/dev/null", nullptr, O_RDONLY, errorBuffer);
     if (!m_kd) {
-        qWarning() << errorBuffer;
+        qCWarning(KSYSTEMSTATS_MEMORY) << errorBuffer;
     }
 }
 
@@ -56,7 +58,8 @@ void FreeBsdMemoryBackend::makeSensors()
     m_cache = cacheSensor;
     m_sysctlSensors.push_back(cacheSensor);
 
-    auto bufferSensor = new KSysGuard::SysctlSensor<uint64_t>(QStringLiteral("buffer"), "vfs.bufspace", m_physicalObject);
+    // uint64_t can't be used here, because it's mapped to Qt type ulong, which is not registered in Qt DBus type system. See https://doc.qt.io/qt-6/qdbustypesystem.html
+    auto bufferSensor = new KSysGuard::SysctlSensor<unsigned long long>(QStringLiteral("buffer"), "vfs.bufspace", m_physicalObject);
     m_buffer = bufferSensor;
     m_sysctlSensors.push_back(bufferSensor);
 
@@ -68,7 +71,7 @@ void FreeBsdMemoryBackend::makeSensors()
 
 unsigned long long FreeBsdMemoryBackend::pagesToBytes(uint32_t pages)
 {
-    return m_pageSize * pages;
+    return m_pageSize * static_cast<unsigned long long>(pages);
 }
 
 void FreeBsdMemoryBackend::update()
