@@ -78,8 +78,8 @@ int main(int argc, char **argv)
 
 SensorWatcher::SensorWatcher(int &argc, char **argv)
     : QCoreApplication(argc, argv)
-    , m_iface(new KSysGuard::SystemStats::DBusInterface("org.kde.ksystemstats",
-          "/",
+    , m_iface(new KSysGuard::SystemStats::DBusInterface(KSysGuard::SystemStats::ServiceName,
+          KSysGuard::SystemStats::ObjectPath,
           QDBusConnection::sessionBus(),
           this))
 {
